# build mod_wsgi
%bcond_with wsgi

# build http_geoip_module
%if "%{_dist_release}" >= "vl7"
%bcond_without geoip
%else
%bcond_with geoip
%endif

%if "%{_dist_release}" > "vl6"
%define nginx_user      www-data
%else
%define nginx_user      nginx
%endif
%define nginx_group     %{nginx_user}
%define nginx_home      %{_localstatedir}/lib/nginx
%define nginx_home_tmp  %{nginx_home}/tmp
%define nginx_home_cache %{nginx_home}/cache
%define nginx_logdir    %{_localstatedir}/log/nginx
%define nginx_confdir   %{_sysconfdir}/nginx
%define nginx_datadir   %{_datadir}/nginx
%define nginx_webroot   %{nginx_datadir}/html

Summary:        Robust, small and high performance http and reverse proxy server
Summary(ja):    堅牢・軽量・高性能な HTTP およびリバースプロキシサーバ
Name:           nginx
Version:        1.11.13
Release:        1%{?_dist_release}

Group:          System Environment/Daemons   
# BSD License (two clause)
# http://www.freebsd.org/copyright/freebsd-license.html
License:        BSD
URL:            http://nginx.net/ 

Source0:    http://sysoev.ru/nginx/nginx-%{version}.tar.gz
Source1:    %{name}.init
Source2:    %{name}.logrotate
Source3:    nginx-virtual.conf.template
Source4:    nginx-ssl.conf
Source5:    %{name}.sysconfig
Source10:   nginx-vine.conf
Source11:   nginx-default-vine
Source20:   proxy_cache.conf
Source100:  nginx-index.html
Source101:  poweredby-vine.png
Source102:  nginx-logo.png
Source103:  nginx-50x.html
Source104:  nginx-404.html
%define ngx_fancyindex_version 0.3.5
Source1000: ngx-fancyindex-%{ngx_fancyindex_version}.tar.xz
%define nginx_accept_language_module_version 02262ce
Source1010: giom-nginx_accept_language_module-%{nginx_accept_language_module_version}.tar.gz

## https://github.com/phusion/passenger/archive/release-%{passenger_version}.tar.gz
%define passenger_version 5.1.2
Source1020: passenger-%{passenger_version}.tar.gz
%define upstream_fair_version 2131c73
Source1030: gnosek-nginx-upstream-fair-%{upstream_fair_version}.tar.gz

%define mod_wsgi_version 6975f0ec7eeb
Source2000: lifeeth-mod_wsgi-%{mod_wsgi_version}.tar.bz2

# removes -Werror in upstream build scripts.  -Werror conflicts with
# -D_FORTIFY_SOURCE=2 causing warnings to turn into errors.
Patch0:     nginx-auto-cc-gcc.patch

# to fix https://svn.boost.org/trac/boost/ticket/8731
Patch100:   boost-changeset_84950.diff

# to fix https://github.com/gnosek/nginx-upstream-fair/pull/23
Patch101:   gnosek-nginx-upstream-fair-pull-23.patch

# to fix compile error with C++11.
Patch1000: passenger-5.0.28-boost.patch


BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root

%if "%{_dist_release}" > "vl6"
BuildRequires:      libboost-devel
%endif
BuildRequires:      pcre-devel
BuildRequires:      zlib-devel
BuildRequires:      openssl-devel
BuildRequires:	    gd-devel
BuildRequires:      perl
BuildRequires:      perl(ExtUtils::Embed)
BuildRequires:	    libxml2-devel
BuildRequires:	    libxslt-devel
BuildRequires:	    curl-devel
%if %{with geoip}
BuildRequires:	    GeoIP-devel
%endif

Requires:           perl(:MODULE_COMPAT_%(eval "`%{__perl} -V:version`"; echo $version))
# for /usr/sbin/useradd
Requires(pre):      shadow-utils
Requires(post):     chkconfig
# for /sbin/service
Requires(preun):    chkconfig, initscripts
Requires(postun):   initscripts
%if "%{_dist_release}" > "vl6"
Requires(pre):	    www-common
%endif

Provides: webserver

Vendor: Project Vine
Distribution: Vine Linux
Packager: daisuke

%description
Nginx [engine x] is an HTTP(S) server, HTTP(S) reverse proxy and IMAP/POP3
proxy server written by Igor Sysoev.

%description -l ja
Nginx [engine x/エンジンX] は Igor Sysoev により開発された以下の機能をもつ
堅牢・軽量・高性能なHTTPサーバかつリバースプロキシサーバです。
 - HTTP(S) サーバ
 - HTTP(S) リバースプロキシサーバ
 - IMAP/POP3 プロキシサーバ

%package passenger
Summary: Nginx with mod_passenger support
Summary(ja): Passenger サポート入りの Nginx 
Group: System Environment/Daemons
BuildRequires: ruby, rubygem-rake
Requires: ruby, rubygem-rake
%if "%{_dist_release}" >= "vl7"
BuildRequires: ruby-devel, ruby-rubygems
Requires: ruby-rubygems
%else
BuildRequires: rubygems
Requires: rubygems
%endif
Requires: nginx

%description passenger
Nginx [engine x] is an HTTP(S) server, HTTP(S) reverse proxy and IMAP/POP3
This package contains nginx server with passenger support.

%description -l ja passenger
Nginx [engine x/エンジンX] は Igor Sysoev により開発された以下の機能をもつ
堅牢・軽量・高性能なHTTPサーバかつリバースプロキシサーバです。
 - HTTP(S) サーバ
 - HTTP(S) リバースプロキシサーバ
 - IMAP/POP3 プロキシサーバ
このパッケージには Passenger サポートを含んだ nginxサーバが入っています。

%prep
%setup -q -a 1000 -a 1010 -a 1020 -a 1030 %{?with_wsgi:-a 2000}

%patch0 -p0

# pushd passenger-%{passenger_version}/ext/
# %patch100 -p2
# popd

pushd gnosek-nginx-upstream-fair-%{upstream_fair_version}
%patch101 -p1
popd

%if %{?_dist_release} == "vl7"
pushd passenger-%{passenger_version}
#% patch1000 -p1
popd
%endif

%build
# nginx does not utilize a standard configure script.  It has its own
# and the standard configure options cause the nginx configure script
# to error out.  This is is also the reason for the DESTDIR environment
# variable.  The configure script(s) have been patched (Patch1 and
# Patch2) in order to support installing into a build environment.

export DESTDIR=%{buildroot}


CONFIGOPTS="\
    --user=%{nginx_user} \
    --group=%{nginx_group} \
    --prefix=%{nginx_datadir} \
    --sbin-path=%{_sbindir}/%{name} \
    --conf-path=%{nginx_confdir}/%{name}.conf \
    --error-log-path=%{nginx_logdir}/error.log \
    --http-log-path=%{nginx_logdir}/access.log \
    --http-client-body-temp-path=%{nginx_home_tmp}/client_body \
    --http-proxy-temp-path=%{nginx_home_tmp}/proxy \
    --http-fastcgi-temp-path=%{nginx_home_tmp}/fastcgi \
    --pid-path=%{_localstatedir}/run/%{name}.pid \
    --lock-path=%{_localstatedir}/lock/subsys/%{name} \
    --with-file-aio \
    --with-ipv6 \
    --with-http_ssl_module \
    --with-http_v2_module \
    --with-http_realip_module \
    --with-http_addition_module \
    --with-http_xslt_module \
    --with-http_image_filter_module \
%if %{with geoip}
    --with-http_geoip_module \
%endif
    --with-http_sub_module \
    --with-http_dav_module \
    --with-http_flv_module \
    --with-http_mp4_module \
    --with-http_gunzip_module \
    --with-http_gzip_static_module \
    --with-http_auth_request_module \
    --with-http_random_index_module \
    --with-http_secure_link_module \
    --with-http_degradation_module \
    --with-http_stub_status_module \
    --with-http_perl_module \
    --with-mail \
    --with-mail_ssl_module \
    --add-module=ngx-fancyindex-%{ngx_fancyindex_version} \
    --add-module=giom-nginx_accept_language_module-%{nginx_accept_language_module_version} \
    --add-module=gnosek-nginx-upstream-fair-%{upstream_fair_version} \
%if %{with wsgi}
    --add-module=lifeeth-mod_wsgi-%{mod_wsgi_version} \
%endif
%ifarch i686
    --with-cpu-opt=pentiumpro \
    --with-zlib-asm=pentiumpro \
    --with-md5-asm \
    --with-sha1-asm \
%endif
"


## build with passenger
./configure \
    $CONFIGOPTS \
    --with-cc-opt="%{optflags}" \
    --add-module=passenger-%{passenger_version}/src/nginx_module

make %{?_smp_mflags} 
mv objs/nginx objs/nginx.passenger

## build without passenger
./configure \
    $CONFIGOPTS \
    --with-cc-opt="%{optflags}"

make %{?_smp_mflags} 

%install
rm -rf %{buildroot}
make install DESTDIR=%{buildroot} INSTALLDIRS=vendor
find %{buildroot} -type f -name .packlist -exec rm -f {} \;
find %{buildroot} -type f -name perllocal.pod -exec rm -f {} \;
find %{buildroot} -type f -empty -exec rm -f {} \;
find %{buildroot} -type f -exec chmod 0644 {} \;
find %{buildroot} -type f -name '*.so' -exec chmod 0755 {} \;
mv  %{buildroot}%{_sbindir}/nginx %{buildroot}%{_sbindir}/nginx.normal
%{__install} -m 0755 objs/nginx.passenger %{buildroot}%{_sbindir}/
chmod 0755 %{buildroot}%{_sbindir}/nginx.*
%{__install} -p -D -m 0755 %{SOURCE1} %{buildroot}%{_initrddir}/%{name}
%{__install} -p -D -m 0644 %{SOURCE2} %{buildroot}%{_sysconfdir}/logrotate.d/%{name}
%{__install} -p -D -m 0644 %{SOURCE5} %{buildroot}%{_sysconfdir}/sysconfig/%{name}
%{__install} -p -d -m 0755 %{buildroot}%{nginx_confdir}/conf.d
%{__install} -p -d -m 0755 %{buildroot}%{nginx_confdir}/sites.d
%{__install} -p -m 0644 %{SOURCE3} %{buildroot}%{nginx_confdir}/sites.d/virtual.conf.template
%{__install} -p -m 0644 %{SOURCE4} %{buildroot}%{nginx_confdir}/conf.d/ssl.conf
%{__sed} -e 's/__NGINXUSER__/%{nginx_user}/g' %{SOURCE10} > %{buildroot}%{nginx_confdir}/nginx.conf
%{__cp} %{buildroot}%{nginx_confdir}/nginx.conf %{buildroot}%{nginx_confdir}/nginx.conf.default
%{__install} -p -m 0644 %{SOURCE11} %{buildroot}%{nginx_confdir}/sites.d/default
%{__install} -p -m 0644 %{SOURCE20} %{buildroot}%{nginx_confdir}/conf.d/proxy_cache.conf
%{__install} -p -d -m 0755 %{buildroot}%{nginx_home_cache}
%{__install} -p -d -m 0755 %{buildroot}%{nginx_home_tmp}
%{__install} -p -d -m 0755 %{buildroot}%{nginx_logdir}
%{__install} -p -d -m 0755 %{buildroot}%{nginx_webroot}
%{__install} -p -m 0644 %{SOURCE100} %{buildroot}%{nginx_webroot}/index.html
%{__install} -p -m 0644 %{SOURCE101} %{buildroot}%{nginx_webroot}/poweredby.png
%{__install} -p -m 0644 %{SOURCE102} %{buildroot}%{nginx_webroot}/nginx-logo.png
%{__install} -p -m 0644 %{SOURCE103} %{buildroot}%{nginx_webroot}/50x.html
%{__install} -p -m 0644 %{SOURCE104} %{buildroot}%{nginx_webroot}/404.html

%if %{with wsgi}
%{__install} -p -m 0644 \
    lifeeth-mod_wsgi-%{mod_wsgi_version}/conf/wsgi_vars \
    %{buildroot}%{nginx_confdir}
cp -f lifeeth-mod_wsgi-%{mod_wsgi_version}/README README.mod_wsgi
%endif

# upstream fair module document
cp -f gnosek-nginx-upstream-fair-%{upstream_fair_version}/README README.upstream_fair

touch %{buildroot}%{nginx_confdir}/conf.d/virtual.conf

# convert to UTF-8 all files that give warnings.
for textfile in CHANGES
do
    mv $textfile $textfile.old
    iconv --from-code ISO8859-1 --to-code UTF-8 --output $textfile $textfile.old
    rm -f $textfile.old
done

%clean
rm -rf %{buildroot}

%post
if [ $1 == 1 ]; then
    /sbin/chkconfig --add %{name}
fi
update-alternatives --install %{_sbindir}/nginx nginx %{_sbindir}/nginx.normal 20

%post passenger
update-alternatives --install %{_sbindir}/nginx nginx %{_sbindir}/nginx.passenger 30

%preun
if [ $1 = 0 ]; then
    /sbin/service %{name} stop >/dev/null 2>&1
    /sbin/chkconfig --del %{name}
    update-alternatives --remove nginx %{_sbindir}/nginx.normal
fi

%preun passenger
if [ $1 = 0 ]; then
    update-alternatives --remove nginx %{_sbindir}/nginx.passenger
fi


%postun
if [ $1 == 2 ]; then
    /sbin/service %{name} upgrade || :
fi

%files
%defattr(-,root,root,-)
%doc LICENSE CHANGES README 
%doc README.upstream_fair
%doc %{?with_wsgi:README.mod_wsgi}
%{nginx_datadir}/
%{_sbindir}/%{name}.normal
%{_mandir}/man3/%{name}.3pm.gz
%{_initrddir}/%{name}
%dir %{nginx_confdir}
%dir %{nginx_confdir}/conf.d
%config(noreplace) %{nginx_confdir}/conf.d/*.conf
%ghost %config(noreplace) %{nginx_confdir}/conf.d/virtual.conf
%config(noreplace) %{nginx_confdir}/sites.d/*
%config(noreplace) %{nginx_confdir}/win-utf
%config(noreplace) %{nginx_confdir}/%{name}.conf.default
%config(noreplace) %{nginx_confdir}/mime.types.default
%config(noreplace) %{nginx_confdir}/fastcgi_params
%config(noreplace) %{nginx_confdir}/fastcgi_params.default
%config(noreplace) %{nginx_confdir}/koi-win
%config(noreplace) %{nginx_confdir}/koi-utf
%config(noreplace) %{nginx_confdir}/%{name}.conf
%config(noreplace) %{nginx_confdir}/mime.types
%config(noreplace) %{nginx_confdir}/fastcgi.conf
%config(noreplace) %{nginx_confdir}/fastcgi.conf.default
%config(noreplace) %{nginx_confdir}/scgi_params
%config(noreplace) %{nginx_confdir}/scgi_params.default
%config(noreplace) %{nginx_confdir}/uwsgi_params
%config(noreplace) %{nginx_confdir}/uwsgi_params.default
%if %{with wsgi}
%config(noreplace) %{nginx_confdir}/wsgi_vars
%endif
%config(noreplace) %{_sysconfdir}/logrotate.d/%{name}
%config(noreplace) %{_sysconfdir}/sysconfig/%{name}
%dir %{perl_vendorarch}/auto/%{name}
%{perl_vendorarch}/%{name}.pm
%{perl_vendorarch}/auto/%{name}/%{name}.so
%attr(-,%{nginx_user},%{nginx_group}) %dir %{nginx_home}
%attr(-,%{nginx_user},%{nginx_group}) %dir %{nginx_home_tmp}
%attr(-,%{nginx_user},%{nginx_group}) %dir %{nginx_home_cache}
%attr(-,%{nginx_user},%{nginx_group}) %dir %{nginx_logdir}

%files passenger
%defattr(-,root,root,-)
%doc passenger-%{passenger_version}/doc/*.md
%doc passenger-%{passenger_version}/doc/*.txt
%doc passenger-%{passenger_version}/doc/*.html
%doc passenger-%{passenger_version}/doc/templates
%doc passenger-%{passenger_version}/doc/users_guide_snippets
%doc passenger-%{passenger_version}/doc/images
%{_sbindir}/%{name}.passenger


%changelog
* Wed Apr  5 2017 Munehiro Yamamoto <munepi@vinelinux.org> 1.11.13-1
- updated to 1.11.13

* Sat Mar 25 2017 Munehiro Yamamoto <munepi@vinelinux.org> 1.11.12-1
- updated to 1.11.12

* Tue Mar  7 2017 Munehiro Yamamoto <munepi@vinelinux.org> 1.11.10-1
- updated to 1.11.10
- updated passenger to 5.1.2

* Tue Jan 31 2017 Munehiro Yamamoto <munepi@vinelinux.org> 1.11.9-1
- updated to 1.11.9

* Wed Dec 28 2016 Munehiro Yamamoto <munepi@vinelinux.org> 1.11.8-1
- updated to 1.11.8

* Sat Nov 19 2016 Munehiro Yamamoto <munepi@vinelinux.org> 1.11.6-1
- updated to 1.11.6
- applied gnosek-nginx-upstream-fair-pull-23.patch against nginx-1.11.6

* Mon Sep  5 2016 Munehiro Yamamoto <munepi@vinelinux.org> 1.11.3-1
- updated to 1.11.3
- updated passenger to 5.0.30

* Fri Sep 02 2016 Toshiaki Ara <ara_t@384.jp> 1.10.1-2
- rebuild with gcc-5.4.0

* Tue Jun 7 2016 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 1.10.1-1
- updated to 1.10.1.
- updated passenger to 5.0.28.

* Wed Apr 20 2016 Munehiro Yamamoto <munepi@vinelinux.org> 1.9.15-1
- updated to 1.9.15

* Thu Apr  7 2016 Munehiro Yamamoto <munepi@vinelinux.org> 1.9.14-1
- updated to 1.9.14
- updated passenger to 5.0.27

* Wed Apr  6 2016 Munehiro Yamamoto <munepi@vinelinux.org> 1.9.13-1
- new upstream release

* Mon Mar 14 2016 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 1.9.12-1
- updated to 1.9.12.
- updated passenger to 5.0.26.

* Wed Feb 17 2016 Munehiro Yamamoto <munepi@vinelinux.org> 1.9.11-1
- new upstream release

* Wed Feb  3 2016 Munehiro Yamamoto <munepi@vinelinux.org> 1.9.10-1
- update to 1.9.10
- update passenger to 5.0.24

* Sun Jan 10 2016 Munehiro Yamamoto <munepi@vinelinux.org> 1.9.9-2
- update passenger to 5.0.23

* Sun Dec 20 2015 Munehiro Yamamoto <munepi@vinelinux.org> 1.9.9-1
- new upstream release

* Sat Dec  5 2015 Munehiro Yamamoto <munepi@vinelinux.org> 1.9.7-1
- new upstream release

* Sat Oct 10 2015 Munehiro Yamamoto <munepi@vinelinux.org> 1.9.5-1
- new upstream release

* Sun Aug 23 2015 Munehiro Yamamoto <munepi@vinelinux.org> 1.9.4-1
- new upstream release

* Thu Jul 16 2015 Munehiro Yamamoto <munepi@vinelinux.org> 1.9.3-1
- update to 1.9.3
- update passenger to 5.0.11

* Thu Jun 25 2015 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 1.9.2-2
- updated Source4 (ssl.conf).

* Wed Jun 17 2015 Munehiro Yamamoto <munepi@vinelinux.org> 1.9.2-1
- update to 1.9.2
- update passenger to 5.0.10
- update ngx-fancyindex to 0.3.5

* Thu Sep 25 2014 Daisuke SUZUKI <daisuke@vinelinux.org> 1.6.2-1
- update to 1.6.2
- update passenger to 4.0.52

* Fri Aug 08 2014 Daisuke SUZUKI <daisuke@vinelinux.org> 1.6.1-1
- new upstream release

* Mon Jun 30 2014 Daisuke SUZUKI <daisuke@vinelinux.org> 1.6.0-3
- rebuild with new environment

* Mon Jun 23 2014 Daisuke SUZUKI <daisuke@vinelinux.org> 1.6.0-2
- update passenger to 4.0.45

* Fri Apr 25 2014 Daisuke SUZUKI <daisuke@linux.or.jp> 1.6.0-1
- update to 1.6.0 (stable)

* Thu Feb 20 2014 Daisuke SUZUKI <daisuke@linux.or.jp> 1.5.10-2
- update fancyindex to 0.3.3

* Wed Feb 12 2014 Daisuke SUZUKI <daisuke@linux.or.jp> 1.5.10-1
- update to 1.5.10
- update passenger to 4.0.37

* Sat Jan 04 2014 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 1.5.6-2
- rebuilt with GeoIP-1.6.0.
- added Patch100.

* Tue Oct 29 2013 Daisuke SUZUKI <daisuke@linux.or.jp> 1.5.6-1
- update to 1.5.6
- update passenger to 4.0.21

* Wed Oct 02 2013 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 1.4.1-2
- rebuilt with gd-2.1.0.

* Wed May 08 2013 Daisuke SUZUKI <daisuke@linux.or.jp> 1.4.1-1
- update to 1.4.1

* Mon Apr 29 2013 Daisuke SUZUKI <daisuke@linux.or.jp> 1.4.0-1
- update to 1.4.0
- enable SPDY module

* Wed Feb 13 2013 Daisuke SUZUKI <daisuke@linux.or.jp> 1.2.7-1
- new upstream release
- update passenger to 3.0.19
- update ngx-fancyindex to upstream git master

* Thu Nov 29 2012 Daisuke SUZUKI <daisuke@linux.or.jp> 1.2.5-1
- new upstream release
- update passenger to 3.0.17

* Wed Oct 24 2012 Daisuke SUZUKI <daisuke@linux.or.jp> 1.2.4-3
- rebuild with pcre-8.31

* Tue Oct 09 2012 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 1.2.4-2
- added http_geoip_module.

* Tue Sep 25 2012 Daisuke SUZUKI <daisuke@linux.or.jp> 1.2.4-1
- update to 1.2.4

* Thu Jul 19 2012 Daisuke SUZUKI <daisuke@linux.or.jp> 1.2.2-1
- update to 1.2.2

* Thu Jun 28 2012 Daisuke SUZUKI <daisuke@linux.or.jp> 1.2.1-1
- update to 1.2.1
- change nginx user from nginx to www-data
- R(pre): www-common

* Wed Apr 25 2012 Daisuke SUZUKI <daisuke@linux.or.jp> 1.2.0-1
- update to 1.2.0
- update passenger to 3.0.12
- drop http_upstream_keepalive

* Mon Mar 19 2012 Daisuke SUZUKI <daisuke@linux.or.jp> 1.0.14-1
- new upstream release 

* Thu Feb 23 2012 Daisuke SUZUKI <daisuke@linux.or.jp> 1.0.12-1
- update to 1.0.12

* Tue Jan 10 2012 Daisuke SUZUKI <daisuke@linux.or.jp> 1.0.11-1
- update to 1.0.11
- update passenger to 3.0.11

* Mon Nov 21 2011 Daisuke SUZUKI <daisuke@linux.or.jp> 1.0.10-1
- update to 1.0.10

* Tue Sep 27 2011 Daisuke SUZUKI <daisuke@linux.or.jp> 1.0.6-2
- update passenger to 3.0.9

* Tue Aug 30 2011 Daisuke SUZUKI <daisuke@linux.or.jp> 1.0.6-1
- update to 1.0.6

* Thu Jun 09 2011 Daisuke SUZUKI <daisuke@linux.or.jp> 1.0.4-1
- update to 1.0.4

* Wed May 18 2011 Daisuke SUZUKI <daisuke@linux.or.jp> 1.0.2-3
- add gnosek-nginx-upstream-fair module
- add ngx_http_upstream_keepalive module

* Wed May 11 2011 Daisuke SUZUKI <daisuke@linux.or.jp> 1.0.2-2
- add nginx-passenger sub pakckage
  - use alternatives to choose nginx with or without passenger
  - add BR: ruby, rubygems, rubygem-rake

* Wed May 11 2011 Daisuke SUZUKI <daisuke@linux.or.jp> 1.0.2-1
- update to 1.0.2

* Wed May 04 2011 Daisuke SUZUKI <daisuke@linux.or.jp> 1.0.1-1
- update to 1.0.1

* Sun May 01 2011 Daisuke SUZUKI <daisuke@linux.or.jp> 1.0.0-2
- add bcond_with wsgi for mod_wsgi
- add bcond_with passenger
  - you need to install rake.gem to build with this option.
- add Provides: webserver

* Tue Apr 12 2011 Daisuke SUZUKI <daisuke@linux.or.jp> 1.0.0-1
- new upstream release 1.0.0!

* Sun Mar 27 2011 Daisuke SUZUKI <daisuke@linux.or.jp> 0.8.54-2
- rebuild with perl-5.12.3

* Mon Jan 17 2011 Daisuke SUZUKI <daisuke@linux.or.jp> 0.8.54-1
- update to 0.8.54

* Sun Nov 28 2010 Daisuke SUZUKI <daisuke@linux.or.jp> 0.8.53-1
- update to 0.8.53
- add nginx_accept_language_module

* Fri Sep 24 2010 Daisuke SUZUKI <daisuke@linux.or.jp> 0.8.50-1
- update to 0.8.50
- update ngx-fancyindex to 0.3
- add BR: libxml2-devel, libxslt-devel
- add scgi_params* and uwsgi_params* to %%files

* Sat Apr 17 2010 Daisuke SUZUKI <daisuke@linux.or.jp> 0.8.35-1
- update to 0.8.35 (development version)
- add sites.d/ to store vitualhost settings
- split out default server settings to sites.d/default
- add fancyindex module

* Fri Dec 04 2009 Daisuke SUZUKI <daisuke@linux.or.jp> 0.7.63-1
- new upstream release

* Sun Sep 20 2009 Shu KONNO <owa@bg.wakwak.com> 0.7.62-1
- update to 0.7.62 (included security fix: VU#180065)

* Wed Aug 26 2009 Daisuke SUZUKI <daisuke@linux.or.jp> 0.7.61-4
- fix typo

* Thu Aug 06 2009 Daisuke SUZUKI <daisuke@linux.or.jp> 0.7.61-3
- add translated descriptions

* Sat Jul 25 2009 Daisuke SUZUKI <daisuke@linux.or.jp> 0.7.61-2
- update 404.html/50x.html to use powered by vine logo.

* Wed Jul 15 2009 Daisuke SUZUKI <daisuke@linux.or.jp> 0.7.61-1
- initial build for Vine Linux
- update to 0.7.61

* Sun May 17 2009 Jeremy Hinegardner <jeremy at hinegardner dot org> - 0.6.36-2
- init script updates from Gena Makhomed
- remove nginx-upstream-fair

* Sat Apr 11 2009 Jeremy Hinegardner <jeremy at hinegardner dot org> - 0.6.36-1
-  update to 0.6.36

* Wed Feb 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.6.35-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Thu Feb 19 2009 Jeremy Hinegardner <jeremy at hinegardner dot org> - 0.6.35-2
- rebuild

* Thu Feb 19 2009 Jeremy Hinegardner <jeremy at hinegardner dot org> - 0.6.35-1
- update to 0.6.35

* Sat Jan 17 2009 Tomas Mraz <tmraz@redhat.com> - 0.6.34-2
- rebuild with new openssl

* Tue Dec 30 2008 Jeremy Hinegardner <jeremy at hinegardner dot org> - 0.6.34-1
- update to 0.6.34

* Thu Dec  4 2008 Michael Schwendt <mschwendt@fedoraproject.org> - 0.6.33-2
- Fix inclusion of /usr/share/nginx tree => no unowned directories.

* Sun Nov 23 2008 Jeremy Hinegardner <jeremy at hinegardner dot org> - 0.6.33-1
- update to 0.6.33

* Tue Jul 22 2008 Jeremy Hinegardner <jeremy at hinegardner dot org> - 0.6.32-1
- update to 0.6.32
- nginx now supports DESTDIR so removed the patches that enabled it 

* Mon May 26 2008 Jeremy Hinegardner <jeremy at hinegardner dot org> - 0.6.31-3
- init script fixes
- resolve 'listen 80 default' [#447873]

* Mon May 12 2008 Jeremy Hinegardner <jeremy at hinegardner dot org> - 0.6.31-2
- update to 0.6.31

* Sun May 11 2008 Jeremy Hinegardner <jeremy at hinegardner dot org> - 0.6.30-2
- upate to new upstream stable branch 0.6
- added 3rd party module nginx-upstream-fair
- added default webpages

* Sun Apr 20 2008 Jeremy Hinegardner <jeremy at hinegardner dot org> - 0.5.35-2
- update init script to match recommended guidelines
- add /etc/nginx/conf.d support [#443280]
- use /etc/sysconfig/nginx to determine nginx.conf [#442708]

* Tue Mar 18 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 0.5.35-3
- add Requires for versioned perl (libperl.so)
- drop silly file Requires

* Tue Feb 19 2008 Fedora Release Engineering <rel-eng@fedoraproject.org> - 0.5.35-2
- Autorebuild for GCC 4.3

* Sat Jan 19 2008 Jeremy Hinegardner <jeremy at hinegardner dot org> - 0.5.35-1
- update to 0.5.35

* Sat Dec 15 2007 Jeremy Hinegardner <jeremy at hinegardner dot org> - 0.5.34-1
- update to 0.5.34

* Wed Dec 05 2007 Release Engineering <rel-eng at fedoraproject dot org> - 0.5.33-2
 - Rebuild for deps

* Sun Nov 11 2007 Jeremy Hinegardner <jeremy@hinegardner.org> - 0.5.33-1
- update to 0.5.33

* Mon Sep 24 2007 Jeremy Hinegardner <jeremy@hinegardner.org> - 0.5.32-1
- updated to 0.5.32
- fixed rpmlint UTF-8 complaints.

* Sat Aug 18 2007 Jeremy Hinegardner <jeremy@hinegardner.org> - 0.5.31-2
- added --with-http_stub_status_module build option.
- added --with-http_sub_module build option.
- added use of pcre-config --cflags

* Fri Aug 17 2007 Jeremy Hinegardner <jeremy@hinegardner.org> - 0.5.31-1
- Update to 0.5.31
- specify license is BSD

* Sat Aug 11 2007 Jeremy Hinegardner <jeremy@hinegardner.org> - 0.5.30-2
- Add BuildRequires: perl-devel - fixing rawhide build

* Mon Jul 30 2007 Jeremy Hinegardner <jeremy@hinegardner.org> - 0.5.30-1
- Update to 0.5.30

* Tue Jul 24 2007 Jeremy Hinegardner <jeremy@hinegardner.org> - 0.5.29-1
- Update to 0.5.29

* Wed Jul 18 2007 Jeremy Hinegardner <jeremy@hinegardner.org> - 0.5.28-1
- Update to 0.5.28

* Mon Jul 09 2007 Jeremy Hinegardner <jeremy@hinegardner.org> - 0.5.27-1
- Update to 0.5.27

* Mon Jun 18 2007 Jeremy Hinegardner <jeremy@hinegardner.org> - 0.5.26-1
- Update to 0.5.26

* Sat Apr 28 2007 Jeremy Hinegardner <jeremy@hinegardner.org> - 0.5.19-1
- Update to 0.5.19

* Mon Apr 02 2007 Jeremy Hinegardner <jeremy@hinegardner.org> - 0.5.17-1
- Update to 0.5.17

* Mon Mar 26 2007 Jeremy Hinegardner <jeremy@hinegardner.org> - 0.5.16-1
- Update to 0.5.16
- add ownership of /usr/share/nginx/html (#233950)

* Fri Mar 23 2007 Jeremy Hinegardner <jeremy@hinegardner.org> - 0.5.15-3
- fixed package review bugs (#235222) given by ruben@rubenkerkhof.com

* Thu Mar 22 2007 Jeremy Hinegardner <jeremy@hinegardner.org> - 0.5.15-2
- fixed package review bugs (#233522) given by kevin@tummy.com

* Thu Mar 22 2007 Jeremy Hinegardner <jeremy@hinegardner.org> - 0.5.15-1
- create patches to assist with building for Fedora
- initial packaging for Fedora
